@@ -400,3 +400,57 @@ Country = Literal[
     "Liberia",
     "Kenya",
 ]
+
+
+HighGrowthIndustry = Literal[
+    "Software - Infrastructure",
+    "Software - Application",
+    "Internet Retail",
+    "Internet Content & Information",
+    "Electronic Gaming & Multimedia",
+    "Semiconductors",
+    "Semiconductor Equipment & Materials",
+    "Information Technology Services",
+    "Communication Equipment",
+    "Consumer Electronics",
+    "Health Information Services",
+    "Biotechnology",
+    "Medical Devices",
+    "Diagnostics & Research",
+    "Medical Instruments & Supplies",
+    "Drug Manufacturers - Specialty & Generic",
+]
+
+DefensiveIndustries = Literal[
+    "Utilities - Independent Power Producers",
+    "Utilities - Diversified",
+    "Utilities - Renewable",
+    "Utilities - Regulated Gas",
+    "Utilities - Regulated Water",
+    "Utilities - Regulated Electric",
+    "Household & Personal Products",
+    "Food Distribution",
+    "Packaged Foods",
+    "Grocery Stores",
+    "Beverages - Non - Alcoholic",
+    "Beverages - Brewers",
+    "Confectioners",
+    "Tobacco",
+    "Paper & Paper Products",
+    "Medical Devices",
+    "Drug Manufacturers - Specialty & Generic",
+    "Medical Instruments & Supplies",
+    "Medical Distribution",
+    "Medical Care Facilities",
+    "Drug Manufacturers - General",
+    "Healthcare Plans",
+    "Pharmaceutical Retailers",
+    "Waste Management",
+    "Pollution & Treatment Controls",
+    "Insurance Brokers",
+    "Insurance - Property & Casualty",
+    "Insurance - Specialty",
+    "Insurance - Reinsurance",
+    "Insurance - Diversified",
+    "Insurance - Life",
+]
