@@ -178,6 +178,7 @@ class GeneralFilter(BaseModel):
     )
     market_capitalization: Optional[List[float]] = Field(default=[5e8, 1e12])
     price_per_earning_ratio: Optional[List[float]] = Field(default=[0.0, 1000.0])
+    last_price: Optional[List[float]] = Field(default=[0.0, 100000.0])
 
 
 class FilterQuery(GeneralFilter, *TechnicalAnalysisFilters, *FundamentalAnalysisFilters):  # type: ignore
@@ -191,7 +192,9 @@ class FilterQuery(GeneralFilter, *TechnicalAnalysisFilters, *FundamentalAnalysis
         )
 
     def to_query(self) -> str:  # noqa: C901
-        parameters = self.model_dump(exclude_defaults=True, exclude_unset=True)
+        parameters = self.model_dump(
+            exclude_defaults=True, exclude_unset=True, exclude={"name"}
+        )
         query = []
         order_by_desc = ""
         order_by_asc = ""
